
int hdmm01_get_data (void)
{
	signed int x_axis_msb, x_axis_lsb, x_axis_val;
	signed int y_axis_msb, y_axis_lsb, y_axis_val;
	int controllreg;
	
	i2c_start(hdmm01_address+I2C_WRITE);
	i2c_write(0x00); //address user register 
	i2c_write(0b10000001); //write user register to trigger measurement
	i2c_stop();
	
	_delay_ms(10); //wait 10ms to let the sensor take the measurement
	
	//get data
	i2c_start(hdmm01_address+I2C_WRITE); 
	i2c_write(0x00);
	
	i2c_rep_start(hdmm01_address+I2C_READ);
	
	controllreg = i2c_readAck();
	x_axis_msb	= i2c_readAck();
	x_axis_lsb	= i2c_readAck();
	y_axis_msb	= i2c_readAck();
	y_axis_lsb	= i2c_readNak();
	
	i2c_stop();
	
	x_axis_val = x_axis_msb *255;
	x_axis_val = x_axis_val + x_axis_lsb;
	
	y_axis_val = y_axis_msb *255;
	y_axis_val = y_axis_val + y_axis_lsb;
	
	return x_axis_val, y_axis_val;
}

int hdmm01_get_axis (char axis)
{
	int axis_msb, axis_lsb, axis_val;
	
	switch (axis)
	{
		//x-axis
		case 'x'	:	i2c_start(hdmm01_address+I2C_WRITE); //read msb
						i2c_write(MSB_X_Axis);
						i2c_rep_start(hdmm01_address+I2C_READ);
						axis_msb = i2c_readNak();
						
						i2c_start(hdmm01_address+I2C_WRITE); //read lsb
						i2c_write(LSB_X_Axis);
						i2c_rep_start(hdmm01_address+I2C_READ);
						axis_lsb = i2c_readNak();
			break;
		
		//y-axis	
		case 'y'	:	i2c_rep_start(hdmm01_address+I2C_WRITE); //read msb
						i2c_write(MSB_Y_Axis);
						i2c_rep_start(hdmm01_address+I2C_READ);
						axis_msb = i2c_readNak();
						
						i2c_rep_start(hdmm01_address+I2C_WRITE); //read lsb
						i2c_write(LSB_Y_Axis);
						i2c_rep_start(hdmm01_address+I2C_READ);
						axis_lsb = i2c_readNak();
			break;
	}
	
	axis_val = axis_msb *255;
	axis_val = axis_val + y_axis_lsb;
	return axis_val;
}

int hdmm01_get_inklination (void)
{
	signed double inkl_stack;
	signed int  x_stack, y_stack;
	
	x_stack = hdmm01_get_axis('x');
	y_stack = hdmm01_get_axis('y');
	
	inkl_stack = hdmm01_calc_theta(y_stack, x_stack);
	
	return inkl_stack;
}

//@in: value of the x-axis and y-axis from the hdmm01
//@out:angle theta between sensor and reference-0
int hdmm01_calc_theta (int y_axis, int x_axis)
{
	/************************************************************************/
	/* To calculate the angle theta between sensor and reference-0 we have */
	/* to convert cartesian koordinates represented through the variables	*/
	/* x_axis and y_axis into the polar koordiantes represented	through an	*/
	/* uncalculated radius r and the searched angle theta.					*/
	/* The conversion x,y=>angle is done be the term theta = arctan(x/y).	*/
	/* Because of the periodicity of the tangens funtion (also the inverse	*/
	/* function arcustangens) we can only calculate the first 180 degrees.	*/
	/* The next 180 degrees we have determine through the quadrants in		*/
	/* the cartesian koordinates are.										*/
	/*																		*/
	/* To determine all the quadrants we have to add or subtract pi.		*/
	/* (I. and IV. Quadrant => normally, II. => +pi, III. => -pi)			*/
	/*																		*/
	/* SO AFTER SOME GOOGLING I HAVE FOUND OUT THAT THE STANDARD FUNCTION	*/
	/* atan2(x,y) DOES ALL THE STUFF NAMED IN THE UPPER PART. *fuuuuuu*		*/
	/*																		*/
 	/* From the function atan2() we get back radiants so we have to convert	*/
	/* it back into degrees throug the function:							*/
	/* 360=2pi rad  => 1rad = 360/2pi	=> 1rad = 180/pi					*/
	/*																		*/
	/* Not implemented is which angle represents which direction. (0 = N?) */
	/************************************************************************/
	
	signed double theta_degrees, theta_radiants;
	double conversionfactor_rad_degree = 180/ PI; 
	
	theta_radiants = atan2(y_axis, x_axis); 
	
	// conversion theta_radiants-degrees
	theta_degrees = theta_radiants * conversionfactor_rad_degree;
	
	return theta_degrees;
}